# datasette-sidebar

[![PyPI](https://img.shields.io/pypi/v/datasette-sidebar.svg)](https://pypi.org/project/datasette-sidebar/)
[![Changelog](https://img.shields.io/github/v/release/datasette/datasette-sidebar?include_prereleases&label=changelog)](https://github.com/datasette/datasette-sidebar/releases)
[![Tests](https://github.com/datasette/datasette-sidebar/actions/workflows/test.yml/badge.svg)](https://github.com/datasette/datasette-sidebar/actions/workflows/test.yml)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/datasette/datasette-sidebar/blob/main/LICENSE)

Add a user-configurable sidebar for staring databases, tables, or apps

## Installation

Install this plugin in the same environment as Datasette.
```bash
datasette install datasette-sidebar
```
## Usage

Usage instructions go here.

## Development

To set up this plugin locally, first checkout the code. You can confirm it is available like this:
```bash
cd datasette-sidebar
# Confirm the plugin is visible
uv run datasette plugins
```
To run the tests:
```bash
uv run pytest
```
